Scoring Functions
=================

Functions for computing 3D similarity scores between molecules.

Constants
---------

.. automodule:: shepherd_score.score.constants
   :members:
   :undoc-members:
   :show-inheritance:

Gaussian Overlap (Shape Similarity)
-----------------------------------

PyTorch Implementation
~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: shepherd_score.score.gaussian_overlap
   :members:
   :undoc-members:
   :show-inheritance:

NumPy Implementation
~~~~~~~~~~~~~~~~~~~~

.. automodule:: shepherd_score.score.gaussian_overlap_np
   :members:
   :undoc-members:
   :show-inheritance:

JAX Implementation
~~~~~~~~~~~~~~~~~~

.. automodule:: shepherd_score.score.gaussian_overlap_jax
   :members:
   :undoc-members:
   :show-inheritance:

Electrostatic Scoring
---------------------

PyTorch Implementation
~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: shepherd_score.score.electrostatic_scoring
   :members:
   :undoc-members:
   :show-inheritance:

NumPy Implementation
~~~~~~~~~~~~~~~~~~~~

.. automodule:: shepherd_score.score.electrostatic_scoring_np
   :members:
   :undoc-members:
   :show-inheritance:

JAX Implementation
~~~~~~~~~~~~~~~~~~

.. automodule:: shepherd_score.score.electrostatic_scoring_jax
   :members:
   :undoc-members:
   :show-inheritance:

Pharmacophore Scoring
---------------------

PyTorch Implementation
~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: shepherd_score.score.pharmacophore_scoring
   :members:
   :undoc-members:
   :show-inheritance:

NumPy Implementation
~~~~~~~~~~~~~~~~~~~~

.. automodule:: shepherd_score.score.pharmacophore_scoring_np
   :members:
   :undoc-members:
   :show-inheritance:

JAX Implementation
~~~~~~~~~~~~~~~~~~

.. automodule:: shepherd_score.score.pharmacophore_scoring_jax
   :members:
   :undoc-members:
   :show-inheritance:
